@@ -17,7 +17,6 @@ import yaml
 
 import monasca_agent.common.aggregator as aggregator
 import monasca_agent.common.check_status as check_status
-import monasca_agent.common.config as config
 import monasca_agent.common.exceptions as exceptions
 import monasca_agent.common.util as util
 
@@ -440,8 +439,8 @@ class AgentCheck(util.Dimensions):
         @return the list of samples
         @rtype list of Measurement objects from monasca_agent.common.metrics
         """
+        metrics = self.aggregator.flush()
         if prettyprint:
-            metrics = self.aggregator.flush()
             for metric in metrics:
                 print(" Timestamp:  {}".format(metric.timestamp))
                 print(" Name:       {}".format(metric.name))
@@ -457,7 +456,7 @@ class AgentCheck(util.Dimensions):
                     print("{0}={1}".format(name, metric.dimensions[name]))
                     line += 1
                 print("-" * 24)
-        return self.aggregator.flush()
+        return metrics
 
     def get_events(self):
         """Return a list of the events saved by the check, if any
